from datetime import datetime
from typing import TYPE_CHECKING, List

from sqlalchemy import Column, DateTime, String
from sqlalchemy.orm import Mapped, relationship

from app.db.base_class import Base

if TYPE_CHECKING:
    from app.models.product import Product


class Supplier(Base):
    """
    Database model for suppliers.
    """
    id = Column(String, primary_key=True, index=True)
    name = Column(String, index=True, nullable=False)
    contact_name = Column(String, nullable=True)
    email = Column(String, nullable=True)
    phone = Column(String, nullable=True)
    address = Column(String, nullable=True)
    notes = Column(String, nullable=True)
    created_at = Column(DateTime, default=datetime.utcnow)
    updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow)
    
    # Relationships
    products: Mapped[List["Product"]] = relationship("Product", back_populates="supplier")